pub struct Listener { /* private fields */ }Expand description
An owned listener for registry events.
This is created by registry::ListenerLocalBuilder and will receive events as long as it is alive.
When this gets dropped, the listener gets unregistered and no events will be received by it.