Struct ListenerLocalBuilder

pub struct ListenerLocalBuilder<'a> { /* private fields */ }
A builder for registering registry event callbacks.

Use Registry::add_listener_local to create this and register callbacks that will be called when events of interest occur. After adding callbacks, use register to get back a registry::Listener.

Examples

let registry_listener = registry.add_listener_local()
    .global(|global| println!("New global: {global:?}"))
    .global_remove(|id| println!("Global with id {id} was removed"))
    .register();

Implementations

Source

impl<'a> ListenerLocalBuilder<'a>

pub fn global<F>(self, global: F) -> Self
where F: Fn(&GlobalObject<&DictRef>) + 'static,

Set the registry global event callback of the listener.

This event is emitted when a new global object is available.

Callback parameters

global: The new global object

Examples
let registry_listener = registry.add_listener_local()
    .global(|global| println!("New global: {global:?}"))
    .register();
pub fn global_remove<F>(self, global_remove: F) -> Self
where F: Fn(u32) + 'static,

Set the registry global_remove event callback of the listener.

This event is emitted when a global object was removed from the registry. If the client has any bindings to the global, it should destroy those.

Callback parameters

id: The id of the global that was removed

Examples
let registry_listener = registry.add_listener_local()
    .global_remove(|id| println!("Global with id {id} was removed"))
    .register();
pub fn register(self) -> Listener

Subscribe to events and register any provided callbacks.