Struct Registry

pub struct Registry(/* private fields */);
Transparent wrapper around a registry.

This does not own the underlying object and is usually seen behind a & reference.

For owning wrappers, see RegistryBox and RegistryRc.

For an explanation of these, see Smart pointers to PipeWire objects.

Implementations

Source

impl Registry

pub fn as_raw(&self) -> &pw_registry

pub fn as_raw_ptr(&self) -> *mut pw_registry

pub fn add_listener_local(&self) -> ListenerLocalBuilder<'_>

pub fn bind<T: ProxyT, P: AsRef<DictRef>>( &self, object: &GlobalObject<P>, ) -> Result<T, Error>

Bind to a global object.

Bind to the global object and get a proxy to the object. After this call, methods can be sent to the remote global object and events can be received.

Usually this is called in callbacks for the global event.

Errors

If T does not match the type of the global object, Error::WrongProxyType is returned.

pub fn destroy_global(&self, global_id: u32) -> SpaResult

Attempt to destroy the global object with the specified id on the remote.

Permissions

Requires X permissions on the global.